getCircleBlur method

Future<double?> getCircleBlur()

Amount to blur the circle. 1 blurs the circle such that only the centerpoint is full opacity. Setting a negative value renders the blur as an inner glow effect. Default value: 0.

Implementation

Future<double?> getCircleBlur() => _annotationMessenger.getCircleBlur(id);