getCirclePitchScale method
Controls the scaling behavior of the circle when the map is pitched. Default value: "map".
Implementation
Future<CirclePitchScale?> getCirclePitchScale() =>
_annotationMessenger.getCirclePitchScale(id);
Controls the scaling behavior of the circle when the map is pitched. Default value: "map".
Future<CirclePitchScale?> getCirclePitchScale() =>
_annotationMessenger.getCirclePitchScale(id);