getCircleSortKey method

Future<double?> getCircleSortKey()

Sorts features in ascending order based on this value. Features with a higher sort key will appear above features with a lower sort key.

Implementation

Future<double?> getCircleSortKey() =>
    _annotationMessenger.getCircleSortKey(id);