setCircleSortKey method

Future<void> setCircleSortKey(
  1. double circleSortKey
)

Sorts features in ascending order based on this value. Features with a higher sort key will appear above features with a lower sort key.

Implementation

Future<void> setCircleSortKey(double circleSortKey) =>
    _annotationMessenger.setCircleSortKey(id, circleSortKey);