FeaturesetFeature class
A basic feature of a featureset.
If you use Standard Style, you can use typed alternatives like StandardPoiFeature, StandardPlaceLabelsFeature, StandardBuildingsFeature.
The featureset feature is different to the Turf.Feature. The latter represents any GeoJSON feature, while the former is a high level representation of features.
- Implementers
Constructors
-
FeaturesetFeature({FeaturesetFeatureId? id, required FeaturesetDescriptor featureset, required Map<
String?, Object?> geometry, required Map<String, Object?> properties, required Map<String, Object?> state})
Properties
- featureset ↔ FeaturesetDescriptor
-
A featureset descriptor denoting the featureset this feature belongs to.
getter/setter pair
-
geometry
↔ Map<
String?, Object?> -
A feature geometry.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ FeaturesetFeatureId?
-
An identifier of the feature.
getter/setter pair
-
properties
↔ Map<
String, Object?> -
Feature JSON properties.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ Map<
String, Object?> -
A feature state.
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → FeaturesetFeature