cluster property

Future<bool?> get cluster

If the data is a collection of point features, setting this to true clusters the points by radius into groups. Cluster groups become new Point features in the source with additional properties:

  • cluster Is true if the point is a cluster
  • cluster_id A unqiue id for the cluster to be used in conjunction with the cluster inspection methods
  • point_count Number of original points grouped into this cluster
  • point_count_abbreviated An abbreviated point count Default value: false.

Implementation

Future<bool?> get cluster async {
  return _style?.getStyleSourceProperty(id, "cluster").then((value) {
    if (value.value != null) {
      return value.value as bool;
    } else {
      return null;
    }
  });
}