ImportPosition class

Specifies the position at which an import will be added when using Style.addImport

Constructors

ImportPosition({String? above, String? below, int? at})

Properties

above String?
Import should be positioned above the specified import id.
getter/setter pair
at int?
Import should be positioned at the specified index in the imports stack.
getter/setter pair
below String?
Import should be positioned below the specified import id.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) ImportPosition