IndoorSelectorSettings class

Settings for the indoor floor selector.

Constructors

IndoorSelectorSettings({bool? enabled, OrnamentPosition? position, double? marginLeft, double? marginTop, double? marginRight, double? marginBottom})

Properties

enabled bool?
Whether the indoor selector is visible on the map. Default value: true.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
marginBottom double?
Defines the margin to the bottom that the indoor selector honors. Default value: 8.
getter/setter pair
marginLeft double?
Defines the margin to the left that the indoor selector honors. Default value: 8.
getter/setter pair
marginRight double?
Defines the margin to the right that the indoor selector honors. Default value: 8.
getter/setter pair
marginTop double?
Defines the margin to the top that the indoor selector honors. Default value: 60.
getter/setter pair
position OrnamentPosition?
Defines where the indoor selector is positioned on the map. Default value: "top-right".
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) IndoorSelectorSettings