LineElevationReference enum

Selects the base of line-elevation. Some modes might require precomputed elevation data in the tileset. Default value: "none".

Inheritance
Available extensions

Values

NONE → const LineElevationReference

Elevated rendering is disabled.

SEA → const LineElevationReference

Elevated rendering is enabled. Use this mode to elevate lines relative to the sea level.

GROUND → const LineElevationReference

Elevated rendering is enabled. Use this mode to elevate lines relative to the ground's height below them.

HD_ROAD_MARKUP → const LineElevationReference

Elevated rendering is enabled. Use this mode to describe additive and stackable features that should exist only on top of road polygons.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LineElevationReference>
A constant List of the values in this enum, in order of their declaration.