MAP_LOADING_ERROR constant

String const MAP_LOADING_ERROR

Describes an error that has occured while loading the Map. The type property defines what resource could not be loaded and the message property will contain a descriptive error message. In case of source or tile loading errors, source-id will contain the id of the source failing. In case of tile loading errors, tile-id will contain the id of the tile

Event data format (Object):
.
├── type - String ("style" | "sprite" | "source" | "tile" | "glyphs")
├── message - String
├── source-id - optional String
└── tile-id - optional Object
    ├── z Number (zoom level)
    ├── x Number (x coorinate)
    └── y Number (y coorinate)

Implementation

static const String MAP_LOADING_ERROR = "map-loading-error";