MapPlayerOptions class

Options for playback when using MapRecorder.

Constructors

MapPlayerOptions({required int playbackCount, required double playbackSpeedMultiplier, required bool avoidPlaybackPauses})

Properties

avoidPlaybackPauses bool
When set to true, the player will try to interpolate actions between short wait actions, to continuously render during the playback. This can help to maintain a consistent load during performance testing.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
playbackCount int
The number of times the sequence is played. If negative, the playback loops indefinitely.
getter/setter pair
playbackSpeedMultiplier double
Multiplies the speed of playback for faster or slower replays. (1 means no change.)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) MapPlayerOptions