MapRecorderOptions class

Options for recording the map when using MapRecorder.

These recordings can be used to debug issues which require multiple steps to reproduce. Additionally, playbacks can be used for performance testing custom scenarios.

Constructors

MapRecorderOptions({int? timeWindow, required bool loggingEnabled, required bool compressed})

Properties

compressed bool
If set to true, the recorded output will be compressed with gzip.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
loggingEnabled bool
If set to true, the recorded API calls will be printed in the logs.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeWindow int?
The maximum duration (in milliseconds) from the current time until API calls are kept. If not specified, all API calls will be kept during the recording, which can lead to significant memory consumption for long sessions.
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) MapRecorderOptions