MapboxHttpService constructor

MapboxHttpService({
  1. required BinaryMessenger binaryMessenger,
  2. required int channelSuffix,
})

Creates a new MapboxHttpService instance

binaryMessenger is used for platform channel communication channelSuffix is used to create a unique channel identifier when multiple instances of the service are needed. This should match the suffix used on the platform side.

Implementation

MapboxHttpService(
    {required this.binaryMessenger, required this.channelSuffix}) {
  _channel = MethodChannel('plugins.flutter.io.${channelSuffix.toString()}',
      const StandardMethodCodec(), binaryMessenger);
}