coordinateBoundsZoomForCameraUnwrapped method
Returns the unwrapped coordinate bounds and zoom for a given camera.
This method is useful if the camera shows the antimeridian.
Implementation
Future<CoordinateBoundsZoom> coordinateBoundsZoomForCameraUnwrapped(
CameraOptions camera) =>
_cameraManager.coordinateBoundsZoomForCameraUnwrapped(camera);