OcclusionOpacityMode enum
Specify how opacity in case of being occluded should be applied Default value: "anchor".
Values
- ANCHOR → const OcclusionOpacityMode
-
Whole symbol is treated as occluded if it's anchor point is occluded
- PIXEL → const OcclusionOpacityMode
-
Occlusion is applied on a per-pixel basis
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OcclusionOpacityMode> - A constant List of the values in this enum, in order of their declaration.