setOfflineMapboxTileCountLimit method
Sets the maximum number of Mapbox-hosted tiles that may be downloaded and stored on the current device.
By default, the limit is set to 6,000.
Once this limit is reached, OfflineRegionObserver.mapboxTileCountLimitExceeded()
fires every additional attempt to download additional tiles until already downloaded tiles are removed
by calling OfflineRegion.purge() API.
@param limit the maximum number of tiles allowed to be downloaded
Implementation
Future<void> setOfflineMapboxTileCountLimit(int arg_limit) async {
final BasicMessageChannel<Object?> channel = BasicMessageChannel<Object?>(
'dev.flutter.pigeon.mapbox_maps_flutter.OfflineRegionManager.setOfflineMapboxTileCountLimit',
codec,
binaryMessenger: _binaryMessenger);
final List<Object?>? replyList =
await channel.send(<Object?>[arg_limit]) as List<Object?>?;
if (replyList == null) {
throw PlatformException(
code: 'channel-error',
message: 'Unable to establish connection on channel.',
);
} else if (replyList.length > 1) {
throw PlatformException(
code: replyList[0]! as String,
message: replyList[1] as String?,
details: replyList[2],
);
} else {
return;
}
}