textTransform property
Specifies how to capitalize text, similar to the CSS text-transform property.
Implementation
TextTransform? textTransform;
Specifies how to capitalize text, similar to the CSS text-transform property.
TextTransform? textTransform;