getIconOptional method

Future<bool?> getIconOptional()

If true, text will display without their corresponding icons when the icon collides with other symbols and the text does not.

Implementation

Future<bool?> getIconOptional() => messager.getIconOptional(id);