getIconTextFit method
Scales the icon to fit around the associated text. Default value: "none".
Implementation
Future<IconTextFit?> getIconTextFit() =>
_annotationMessenger.getIconTextFit(id);
Scales the icon to fit around the associated text. Default value: "none".
Future<IconTextFit?> getIconTextFit() =>
_annotationMessenger.getIconTextFit(id);