getTextOptional method

Future<bool?> getTextOptional()

If true, icons will display without their corresponding text when the text collides with other symbols and the icon does not.

Implementation

Future<bool?> getTextOptional() => messager.getTextOptional(id);