setIconAllowOverlap method
If true, the icon will be visible even if it collides with other previously drawn symbols.
Implementation
Future<void> setIconAllowOverlap(bool iconAllowOverlap) =>
messager.setIconAllowOverlap(id, iconAllowOverlap);
If true, the icon will be visible even if it collides with other previously drawn symbols.
Future<void> setIconAllowOverlap(bool iconAllowOverlap) =>
messager.setIconAllowOverlap(id, iconAllowOverlap);