setIconIgnorePlacement method
If true, other symbols can be visible even if they collide with the icon.
Implementation
Future<void> setIconIgnorePlacement(bool iconIgnorePlacement) =>
messager.setIconIgnorePlacement(id, iconIgnorePlacement);
If true, other symbols can be visible even if they collide with the icon.
Future<void> setIconIgnorePlacement(bool iconIgnorePlacement) =>
messager.setIconIgnorePlacement(id, iconIgnorePlacement);