setIconOffset method

Future<void> setIconOffset(
  1. List<double?> iconOffset
)

Offset distance of icon from its anchor. Positive values indicate right and down, while negative values indicate left and up. Each component is multiplied by the value of icon-size to obtain the final offset in pixels. When combined with icon-rotate the offset will be as if the rotated direction was up. Default value: 0,0.

Implementation

Future<void> setIconOffset(List<double?> iconOffset) =>
    _annotationMessenger.setIconOffset(id, iconOffset);