setIconOptional method
If true, text will display without their corresponding icons when the icon collides with other symbols and the text does not. Default value: false.
Implementation
Future<void> setIconOptional(bool iconOptional) =>
_annotationMessenger.setIconOptional(id, iconOptional);