setIconSize method

Future<void> setIconSize(
  1. double iconSize
)

Scales the original size of the icon by the provided factor. The new pixel size of the image will be the original pixel size multiplied by icon-size. 1 is the original size; 3 triples the size of the image. Default value: 1. Minimum value: 0. The unit of iconSize is in factor of the original icon size.

Implementation

Future<void> setIconSize(double iconSize) =>
    _annotationMessenger.setIconSize(id, iconSize);