setTextField method

Future<void> setTextField(
  1. String textField
)

Value to use for a text label. If a plain string is provided, it will be treated as a formatted with default/inherited formatting options. SDF images are not supported in formatted text and will be ignored. Default value: "".

Implementation

Future<void> setTextField(String textField) =>
    _annotationMessenger.setTextField(id, textField);