setTextIgnorePlacement method
If true, other symbols can be visible even if they collide with the text.
Implementation
Future<void> setTextIgnorePlacement(bool textIgnorePlacement) =>
messager.setTextIgnorePlacement(id, textIgnorePlacement);
If true, other symbols can be visible even if they collide with the text.
Future<void> setTextIgnorePlacement(bool textIgnorePlacement) =>
messager.setTextIgnorePlacement(id, textIgnorePlacement);