tapEvents method

Cancelable tapEvents({
  1. required dynamic onTap(
    1. PolygonAnnotation
    ),
})

Registers tap event callbacks for the annotations managed by this manager.

Note: Tap events will now not propagate to annotations below the topmost one. If you tap on overlapping annotations, only the top annotation's tap event will be triggered.

Implementation

Cancelable tapEvents({required Function(PolygonAnnotation) onTap}) {
  return _annotationInteractionEvents(instanceName: "$_channelSuffix/$id/tap")
      .cast<PolygonAnnotationInteractionContext>()
      .listen((data) => onTap(data.annotation))
      .asCancelable();
}