PolylineAnnotationOptions class
Constructors
-
PolylineAnnotationOptions({required LineString geometry, double? lineElevationGroundScale, LineJoin? lineJoin, double? lineSortKey, double? lineZOffset, double? lineBlur, int? lineBorderColor, double? lineBorderWidth, int? lineColor, double? lineEmissiveStrength, double? lineGapWidth, double? lineOffset, double? lineOpacity, String? linePattern, double? lineWidth, bool? isDraggable, Map<String, Object>? customData})
-
Properties
-
customData
↔ Map<String, Object>?
-
JSON convertible properties associated with the annotation, used to enrich Feature GeoJSON
properties["custom_data"] field.
getter/setter pair
-
geometry
↔ LineString
-
The geometry that determines the location/shape of this annotation
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
isDraggable
↔ bool?
-
Property to determine whether annotation can be manually moved around map.
getter/setter pair
-
lineBlur
↔ double?
-
Blur applied to the line, in pixels.
Default value: 0. Minimum value: 0. The unit of lineBlur is in pixels.
getter/setter pair
-
lineBorderColor
↔ int?
-
The color of the line border. If line-border-width is greater than zero and the alpha value of this color is 0 (default), the color for the border will be selected automatically based on the line color.
Default value: "rgba(0, 0, 0, 0)".
getter/setter pair
-
lineBorderWidth
↔ double?
-
The width of the line border. A value of zero means no border.
Default value: 0. Minimum value: 0.
getter/setter pair
-
lineColor
↔ int?
-
The color with which the line will be drawn.
Default value: "#000000".
getter/setter pair
-
lineElevationGroundScale
↔ double?
-
Controls how much the elevation of lines with
line-elevation-reference set to sea scales with terrain exaggeration. A value of 0 keeps the line at a fixed altitude above sea level. A value of 1 scales the elevation proportionally with terrain exaggeration.
Default value: 0. Value range: 0, 1
getter/setter pair
-
lineEmissiveStrength
↔ double?
-
Controls the intensity of light emitted on the source features.
Default value: 0. Minimum value: 0. The unit of lineEmissiveStrength is in intensity.
getter/setter pair
-
lineGapWidth
↔ double?
-
Draws a line casing outside of a line's actual path. Value indicates the width of the inner gap.
Default value: 0. Minimum value: 0. The unit of lineGapWidth is in pixels.
getter/setter pair
-
lineJoin
↔ LineJoin?
-
The display of lines when joining.
Default value: "miter".
getter/setter pair
-
lineOffset
↔ double?
-
The line's offset. For linear features, a positive value offsets the line to the right, relative to the direction of the line, and a negative value to the left. For polygon features, a positive value results in an inset, and a negative value results in an outset.
Default value: 0. The unit of lineOffset is in pixels.
getter/setter pair
-
lineOpacity
↔ double?
-
The opacity at which the line will be drawn.
Default value: 1. Value range:
0, 1
getter/setter pair
-
linePattern
↔ String?
-
Name of image in sprite to use for drawing image lines. For seamless patterns, image width must be a factor of two (2, 4, 8, ..., 512). Note that zoom-dependent expressions will be evaluated only at integer zoom levels.
getter/setter pair
-
lineSortKey
↔ double?
-
Sorts features in ascending order based on this value. Features with a higher sort key will appear above features with a lower sort key.
getter/setter pair
-
lineWidth
↔ double?
-
Stroke thickness.
Default value: 1. Minimum value: 0. The unit of lineWidth is in pixels.
getter/setter pair
-
lineZOffset
↔ double?
-
Vertical offset from ground, in meters. Not supported for globe projection at the moment.
Default value: 0.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited