RenderFrameFinishedEventData class
Data for the renderFrameFinished event.
Constructors
- RenderFrameFinishedEventData({required EventTimeInterval timeInterval, required RenderMode renderMode, required bool needsRepaint, required bool placementChanged})
-
RenderFrameFinishedEventData.fromJson(Map<
String, dynamic> json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- needsRepaint → bool
-
final
- placementChanged → bool
-
final
- renderMode → RenderMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeInterval → EventTimeInterval
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited