skyAtmosphereHaloColor property
A color applied to the atmosphere sun halo. The alpha channel describes how strongly the sun halo is represented in an atmosphere sky layer.
Implementation
int? skyAtmosphereHaloColor;
A color applied to the atmosphere sun halo. The alpha channel describes how strongly the sun halo is represented in an atmosphere sky layer.
int? skyAtmosphereHaloColor;