timeInterval property
The timeInterval.begin is when source data begins loading, and the timeInterval.end is when source data is loaded.
Implementation
final EventTimeInterval timeInterval;
The timeInterval.begin is when source data begins loading, and the timeInterval.end is when source data is loaded.
final EventTimeInterval timeInterval;