select property
When true, the building is selected. Use this state to create a permanent effect. Note: the select state has a higher priority than highlight.
Implementation
bool? select;
When true, the building is selected. Use this state to create a permanent effect. Note: the select state has a higher priority than highlight.
bool? select;