timeInterval property
The timeInterval.begin is when style data begins loading, and the timeInterval.end is when style data is loaded.
Implementation
final EventTimeInterval timeInterval;
The timeInterval.begin is when style data begins loading, and the timeInterval.end is when style data is loaded.
final EventTimeInterval timeInterval;