maxzoom property

Future<double?> get maxzoom

Maximum zoom level for which tiles are available, as in the TileJSON spec. Data from tiles at the maxzoom are used when displaying the map at higher zoom levels.

Implementation

Future<double?> get maxzoom async {
  return _style?.getStyleSourceProperty(id, "maxzoom").then((value) {
    if (value.value != '<null>') {
      return double.parse(value.value);
    } else {
      return null;
    }
  });
}