minimumTileUpdateInterval property

Future<double?> get minimumTileUpdateInterval

Minimum tile update interval in seconds, which is used to throttle the tile update network requests. If the given source supports loading tiles from a server, sets the minimum tile update interval. Update network requests that are more frequent than the minimum tile update interval are suppressed.

Implementation

Future<double?> get minimumTileUpdateInterval async {
  return _style
      ?.getStyleSourceProperty(id, "minimum-tile-update-interval")
      .then((value) {
    if (value.value != '<null>') {
      return double.parse(value.value);
    } else {
      return null;
    }
  });
}