AnnotationManager class
Factory for creating typed annotation managers.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createCircleAnnotationManager(
{String? id, String? below}) → Future< CircleAnnotationManager> - Creates a CircleAnnotationManager for circle annotations.
-
createPointAnnotationManager(
{String? id, String? below}) → Future< PointAnnotationManager> - Creates a PointAnnotationManager for point annotations.
-
createPolygonAnnotationManager(
{String? id, String? below}) → Future< PolygonAnnotationManager> - Creates a PolygonAnnotationManager for polygon (fill) annotations.
-
createPolylineAnnotationManager(
{String? id, String? below}) → Future< PolylineAnnotationManager> - Creates a PolylineAnnotationManager for polyline annotations.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeAnnotationManager(
BaseAnnotationManager< BaseAnnotationManagerPlatformInterface> manager) → Future<void> - Removes an annotation manager and all annotations created by it.
-
removeAnnotationManagerById(
String id) → Future< void> -
Removes the annotation manager with the given
id. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited