DistanceUnits enum
Supported distance unit types. Default value: "metric".
Values
- METRIC → const DistanceUnits
-
Metric units using meters and kilometers. The scale bar will automatically choose between meters and kilometers based on the distance being displayed for optimal readability.
- IMPERIAL → const DistanceUnits
-
Imperial units using feet for short distances and miles for longer distances. The scale bar will display distances in feet for small distances and automatically switch to miles for longer distances.
- NAUTICAL → const DistanceUnits
-
Nautical units using fathoms for short distances and nautical miles for longer distances. The scale bar will display distances in fathoms for small distances and automatically switch to nautical miles for longer distances. Commonly used for marine and aviation navigation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DistanceUnits> - A constant List of the values in this enum, in order of their declaration.