cluster property
If the data is a collection of point features, setting this to true clusters the points by radius into groups. Cluster groups become new Point features in the source with additional properties:
clusterIstrueif the point is a clustercluster_idA unqiue id for the cluster to be used in conjunction with the cluster inspection methodspoint_countNumber of original points grouped into this clusterpoint_count_abbreviatedAn abbreviated point count Default value: false.
Implementation
Future<bool?> get cluster async {
return _style?.getStyleSourceProperty(id, "cluster").then((value) {
if (value.value != null) {
return value.value as bool;
} else {
return null;
}
});
}