cluster property
If the data is a collection of point features, setting this to true clusters the points by radius into groups. Cluster groups become new Point features in the source with additional properties:
clusterIstrueif the point is a clustercluster_idA unqiue id for the cluster to be used in conjunction with the cluster inspection methodspoint_countNumber of original points grouped into this clusterpoint_count_abbreviatedAn abbreviated point count
Implementation
Future<bool?> get cluster async {
return _style?.getStyleSourceProperty(id, "cluster").then((value) {
if (value.value != '<null>') {
if (Platform.isIOS) {
return value.value.toLowerCase() == '1';
} else {
return value.value.toLowerCase() == 'true';
}
} else {
return null;
}
});
}