heatmapRadius property
Radius of influence of one heatmap point in pixels. Increasing the value makes the heatmap smoother, but less detailed.
Implementation
double? heatmapRadius;
Radius of influence of one heatmap point in pixels. Increasing the value makes the heatmap smoother, but less detailed.
double? heatmapRadius;