modelScaleExpression property
The scale expression of the model, which will overwrite the default scale expression that keeps the model size constant during zoom.
Implementation
String? modelScaleExpression;
The scale expression of the model, which will overwrite the default scale expression that keeps the model size constant during zoom.
String? modelScaleExpression;