MapRecorder class
Records and replays API calls on a map instance.
Recordings can be used to debug issues that require multiple steps to reproduce. Playbacks can also be used for performance testing of custom scenarios.
Note: the raw format produced by stopRecording is experimental and there is no guarantee of version cross-compatibility when feeding it to replay.
- Annotations
-
- @experimental
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getState(
) → Future< String> - Returns a string description of the current playback state.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replay(
Uint8List recordedSequence, {int playbackCount = 1, double playbackSpeedMultiplier = 1.0, bool avoidPlaybackPauses = false}) → Future< void> - Replays a previously-recorded sequence.
-
startRecording(
{Duration? timeWindow, bool loggingEnabled = false, bool compressed = false}) → Future< void> - Begins a recording session.
-
stopRecording(
) → Future< Uint8List> - Stops the current recording session and returns the serialized sequence.
-
togglePause(
) → Future< void> - Pauses or resumes playback.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited