getIconTextFit method
Scales the icon to fit around the associated text.
Implementation
Future<IconTextFit?> getIconTextFit() => messager
.getIconTextFit(id)
.then((value) => value != null ? IconTextFit.values[value] : null);
Scales the icon to fit around the associated text.
Future<IconTextFit?> getIconTextFit() => messager
.getIconTextFit(id)
.then((value) => value != null ? IconTextFit.values[value] : null);