getSymbolZOrder method
Determines whether overlapping symbols in the same layer are rendered in the order that they appear in the data source or by their y-position relative to the viewport. To control the order and prioritization of symbols otherwise, use symbol-sort-key. Default value: "auto".
Implementation
Future<SymbolZOrder?> getSymbolZOrder() =>
_annotationMessenger.getSymbolZOrder(id);