getSymbolZOrder method
Determines whether overlapping symbols in the same layer are rendered in the order that they appear in the data source or by their y-position relative to the viewport. To control the order and prioritization of symbols otherwise, use symbol-sort-key.
Implementation
Future<SymbolZOrder?> getSymbolZOrder() => messager
.getSymbolZOrder(id)
.then((value) => value != null ? SymbolZOrder.values[value] : null);