setIconOptional method

Future<void> setIconOptional(
  1. bool iconOptional
)

If true, text will display without their corresponding icons when the icon collides with other symbols and the text does not.

Implementation

Future<void> setIconOptional(bool iconOptional) =>
    messager.setIconOptional(id, iconOptional);