setTextOptional method
If true, icons will display without their corresponding text when the text collides with other symbols and the icon does not.
Implementation
Future<void> setTextOptional(bool textOptional) =>
messager.setTextOptional(id, textOptional);