setOptionForKey method
Sets additional options for this TileStore that are specific to a data type.
@param key The configuration option that should be changed. @param domain The domain this setting should be applied for. @param value The value for the configuration option, or null if it should be reset.
Implementation
void setOptionForKey(String key, {TileDataDomain? domain, Object? value}) {
_api.setOptionForKey(_CustomTileStoreOptionsKey(key: key), domain, value);
}