TileStoreUsageMode enum

Describes tile store usage modes.

Inheritance
Available extensions

Values

DISABLED → const TileStoreUsageMode

Tile store usage is disabled.

The implementation skips checking tile store when requesting a tile.

READ_ONLY → const TileStoreUsageMode

Tile store enabled for accessing loaded tile packs.

The implementation first checks tile store when requesting a tile. If a tile pack is already loaded, the tile will be extracted and returned. Otherwise, the implementation falls back to requesting the individual tile and storing it in the disk cache.

READ_AND_UPDATE → const TileStoreUsageMode

Tile store enabled for accessing local tile packs and for loading new tile packs from server.

All tile requests are converted to tile pack requests, i.e. the tile pack that includes the requested tile will be loaded, and the tile extracted from it.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TileStoreUsageMode>
A constant List of the values in this enum, in order of their declaration.